Class: AftershipAPI::Model::CustomFieldsTrackingUpdateTrackingBySlugTrackingNumberRequest
- Inherits:
-
Object
- Object
- AftershipAPI::Model::CustomFieldsTrackingUpdateTrackingBySlugTrackingNumberRequest
- Defined in:
- lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#initialize(attributes = {}) ⇒ CustomFieldsTrackingUpdateTrackingBySlugTrackingNumberRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*a) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ CustomFieldsTrackingUpdateTrackingBySlugTrackingNumberRequest
Initializes the object
7 8 9 10 11 12 13 14 15 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 7 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AftershipAPI::CustomFieldsTrackingUpdateTrackingBySlugTrackingNumberRequest` initialize method" end attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 54 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model klass = AftershipAPI::Model.const_get(type) klass.build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 23 def self.attribute_map {} end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 30 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(key) && attributes[key].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[key].is_a?(Array) transformed_hash["#{key}"] = attributes[key].map { |v| _deserialize($1, v) } end elsif !attributes[key].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[key]) end end new(transformed_hash) end |
.openapi_types ⇒ Object
Attribute type mapping.
18 19 20 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 18 def self.openapi_types {} end |
Instance Method Details
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 121 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
100 101 102 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 100 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
106 107 108 109 110 111 112 113 114 115 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 106 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_json(*a) ⇒ Object
135 136 137 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 135 def to_json(*a) to_hash.to_json(*a) end |
#to_s ⇒ String
Returns the string representation of the object
94 95 96 |
# File 'lib/aftership-tracking-sdk/models/custom_fields_tracking_update_tracking_by_slug_tracking_number_request.rb', line 94 def to_s to_hash.to_s end |