Class: AftershipAPI::Model::TrackingCreateTrackingRequest
- Inherits:
-
Object
- Object
- AftershipAPI::Model::TrackingCreateTrackingRequest
- Defined in:
- lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb
Instance Attribute Summary collapse
-
#courier_connection_id ⇒ Object
If you’ve connected multiple accounts for a single carrier on AfterShip, you can now use the courier_connection_id field to tell AfterShip which carrier account you’ve used to handle a shipment so we can track it.
-
#custom_fields ⇒ Object
Custom fields that accept an object with string field.
-
#customer_name ⇒ Object
Customer name of the tracking.
-
#delivery_type ⇒ Object
Shipment delivery type- pickup_at_store- pickup_at_courier- door_to_door delivery_type?: String;.
-
#destination_city ⇒ Object
The city of the recipient’s address.
-
#destination_country_iso3 ⇒ Object
The for more details.
-
#destination_postal_code ⇒ Object
The postal of the recipient’s address.
-
#destination_raw_location ⇒ Object
The shipping address that the shipment is shipping to.
-
#destination_state ⇒ Object
The state of the recipient’s address.
-
#emails ⇒ Object
Email address(es) to receive email notifications.
-
#language ⇒ Object
The recipient’s language.
-
#location_id ⇒ Object
The location_id refers to the place where you fulfilled the items.
-
#next_couriers ⇒ Object
If a shipment has multiple carriers, you can use the next_couriers field to tell AfterShip who the second carrier is.
-
#note ⇒ Object
Text field for the note note?: String;.
-
#order_date ⇒ Object
Order date in YYYY-MM-DDTHH:mm:ssZ format.
-
#order_id ⇒ Object
A globally-unique identifier for the order.
-
#order_id_path ⇒ Object
The URL for the order in your system or store.
-
#order_number ⇒ Object
A unique, human-readable identifier for the order.
-
#order_promised_delivery_date ⇒ Object
The promised delivery date of the order.
-
#origin_city ⇒ Object
The city of the sender’s address.
-
#origin_country_iso3 ⇒ Object
The for more details.
-
#origin_postal_code ⇒ Object
The postal of the sender’s address.
-
#origin_raw_location ⇒ Object
The sender address that the shipment is shipping from.
-
#origin_state ⇒ Object
The state of the sender’s address.
-
#pickup_location ⇒ Object
Shipment pickup location for receiver pickup_location?: String;.
-
#pickup_note ⇒ Object
Shipment pickup note for receiver pickup_note?: String;.
-
#shipment_tags ⇒ Object
Used to add tags to your shipments to help categorize and filter them easily.
-
#shipment_type ⇒ Object
The carrier service type for the shipment.
-
#shipping_method ⇒ Object
The shipping_method string refers to the chosen method for delivering the package.
-
#slug ⇒ Object
Unique courier code.
-
#slug_group ⇒ Object
Slug group is a group of slugs which belong to same courier.
-
#smses ⇒ Object
The phone number(s) to receive sms notifications.
-
#title ⇒ Object
By default this field shows the
tracking_number, but you can customize it as you wish with any info (e.g. the order number). -
#tracking_account_number ⇒ Object
Additional field required by some carriers to retrieve the tracking info.
-
#tracking_destination_country ⇒ Object
(Legacy) Replaced by
destination_country_iso3. -
#tracking_key ⇒ Object
Additional field required by some carriers to retrieve the tracking info.
-
#tracking_number ⇒ Object
Tracking number of a shipment.Duplicated tracking numbers, tracking numbers with invalid tracking number format will not be accepted.We only accept tracking numbers with length from 4 to 100We currently support the following characters in a tracking number:- A - Z- 0 - 9-
-(Hyphen)- . -
#tracking_origin_country ⇒ Object
(Legacy) Replaced by
origin_country_iso3. -
#tracking_postal_code ⇒ Object
(Legacy) Replaced by
destination_postal_code. -
#tracking_ship_date ⇒ Object
Additional field required by some carriers to retrieve the tracking info.
-
#tracking_state ⇒ Object
(Legacy) Replaced by
destination_state.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#initialize(attributes = {}) ⇒ TrackingCreateTrackingRequest
constructor
Initializes the object.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
- #to_json(*a) ⇒ Object
-
#to_s ⇒ String
Returns the string representation of the object.
Constructor Details
#initialize(attributes = {}) ⇒ TrackingCreateTrackingRequest
Initializes the object
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 171 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AftershipAPI::TrackingCreateTrackingRequest` initialize method" end attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.key?(:'tracking_number') self.tracking_number = attributes[:'tracking_number'] end if attributes.key?(:'slug') self.slug = attributes[:'slug'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'order_id') self.order_id = attributes[:'order_id'] end if attributes.key?(:'order_id_path') self.order_id_path = attributes[:'order_id_path'] end if attributes.key?(:'custom_fields') self.custom_fields = attributes[:'custom_fields'] end if attributes.key?(:'language') self.language = attributes[:'language'] end if attributes.key?(:'order_promised_delivery_date') self.order_promised_delivery_date = attributes[:'order_promised_delivery_date'] end if attributes.key?(:'delivery_type') self.delivery_type = attributes[:'delivery_type'] end if attributes.key?(:'pickup_location') self.pickup_location = attributes[:'pickup_location'] end if attributes.key?(:'pickup_note') self.pickup_note = attributes[:'pickup_note'] end if attributes.key?(:'tracking_account_number') self.tracking_account_number = attributes[:'tracking_account_number'] end if attributes.key?(:'tracking_key') self.tracking_key = attributes[:'tracking_key'] end if attributes.key?(:'tracking_ship_date') self.tracking_ship_date = attributes[:'tracking_ship_date'] end if attributes.key?(:'emails') self.emails = attributes[:'emails'] end if attributes.key?(:'smses') self.smses = attributes[:'smses'] end if attributes.key?(:'customer_name') self.customer_name = attributes[:'customer_name'] end if attributes.key?(:'origin_country_iso3') self.origin_country_iso3 = attributes[:'origin_country_iso3'] end if attributes.key?(:'origin_state') self.origin_state = attributes[:'origin_state'] end if attributes.key?(:'origin_city') self.origin_city = attributes[:'origin_city'] end if attributes.key?(:'origin_postal_code') self.origin_postal_code = attributes[:'origin_postal_code'] end if attributes.key?(:'origin_raw_location') self.origin_raw_location = attributes[:'origin_raw_location'] end if attributes.key?(:'destination_country_iso3') self.destination_country_iso3 = attributes[:'destination_country_iso3'] end if attributes.key?(:'destination_state') self.destination_state = attributes[:'destination_state'] end if attributes.key?(:'destination_city') self.destination_city = attributes[:'destination_city'] end if attributes.key?(:'destination_postal_code') self.destination_postal_code = attributes[:'destination_postal_code'] end if attributes.key?(:'destination_raw_location') self.destination_raw_location = attributes[:'destination_raw_location'] end if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'slug_group') self.slug_group = attributes[:'slug_group'] end if attributes.key?(:'order_date') self.order_date = attributes[:'order_date'] end if attributes.key?(:'order_number') self.order_number = attributes[:'order_number'] end if attributes.key?(:'shipment_type') self.shipment_type = attributes[:'shipment_type'] end if attributes.key?(:'shipment_tags') self. = attributes[:'shipment_tags'] end if attributes.key?(:'courier_connection_id') self.courier_connection_id = attributes[:'courier_connection_id'] end if attributes.key?(:'next_couriers') self.next_couriers = attributes[:'next_couriers'] end if attributes.key?(:'tracking_origin_country') self.tracking_origin_country = attributes[:'tracking_origin_country'] end if attributes.key?(:'tracking_destination_country') self.tracking_destination_country = attributes[:'tracking_destination_country'] end if attributes.key?(:'tracking_postal_code') self.tracking_postal_code = attributes[:'tracking_postal_code'] end if attributes.key?(:'tracking_state') self.tracking_state = attributes[:'tracking_state'] end if attributes.key?(:'location_id') self.location_id = attributes[:'location_id'] end if attributes.key?(:'shipping_method') self.shipping_method = attributes[:'shipping_method'] end end |
Instance Attribute Details
#courier_connection_id ⇒ Object
If you’ve connected multiple accounts for a single carrier on AfterShip, you can now use the courier_connection_id field to tell AfterShip which carrier account you’ve used to handle a shipment so we can track it. ( courier_connection_id?: String;
139 140 141 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 139 def courier_connection_id @courier_connection_id end |
#custom_fields ⇒ Object
Custom fields that accept an object with string field. In order to protect the privacy of your customers, do not include any custom_fields?: Object;
27 28 29 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 27 def custom_fields @custom_fields end |
#customer_name ⇒ Object
Customer name of the tracking. customer_name?: String;
71 72 73 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 71 def customer_name @customer_name end |
#delivery_type ⇒ Object
Shipment delivery type- pickup_at_store- pickup_at_courier- door_to_door delivery_type?: String;
39 40 41 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 39 def delivery_type @delivery_type end |
#destination_city ⇒ Object
The city of the recipient’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. destination_city?: String;
103 104 105 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 103 def destination_city @destination_city end |
#destination_country_iso3 ⇒ Object
The for more details. destination_country_iso3?: String;
95 96 97 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 95 def destination_country_iso3 @destination_country_iso3 end |
#destination_postal_code ⇒ Object
The postal of the recipient’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. Also the additional field required by some carriers to retrieve the tracking info. The postal code of the recipient’s address. Refer to our article on for more details. destination_postal_code?: String;
107 108 109 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 107 def destination_postal_code @destination_postal_code end |
#destination_raw_location ⇒ Object
The shipping address that the shipment is shipping to. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. destination_raw_location?: String;
111 112 113 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 111 def destination_raw_location @destination_raw_location end |
#destination_state ⇒ Object
The state of the recipient’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. Also the additional field required by some carriers to retrieve the tracking info. The state/province of the recipient’s address. Refer to our article on for more details. destination_state?: String;
99 100 101 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 99 def destination_state @destination_state end |
#emails ⇒ Object
Email address(es) to receive email notifications. Accept either array or comma separated as input. Supports up to 3 email addresses. emails?: String[];
63 64 65 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 63 def emails @emails end |
#language ⇒ Object
The recipient’s language. If you set up AfterShip notifications in different languages, we use this to send the recipient tracking updates in their preferred language. Use an to specify the language. language?: String;
31 32 33 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 31 def language @language end |
#location_id ⇒ Object
The location_id refers to the place where you fulfilled the items. - If you provide a location_id, the system will automatically use it as the tracking’s origin address. However, passing both location_id and any origin address information simultaneously is not allowed.- Please make sure you add your locations . location_id?: String;
163 164 165 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 163 def location_id @location_id end |
#next_couriers ⇒ Object
If a shipment has multiple carriers, you can use the next_couriers field to tell AfterShip who the second carrier is. This is useful if the first carrier does not send us this information. next_couriers?: NextCouriersTrackingCreateTrackingRequest[];
143 144 145 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 143 def next_couriers @next_couriers end |
#note ⇒ Object
Text field for the note note?: String;
115 116 117 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 115 def note @note end |
#order_date ⇒ Object
Order date in YYYY-MM-DDTHH:mm:ssZ format. e.g. 2021-07-26T11:23:51-05:00 order_date?: String;
123 124 125 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 123 def order_date @order_date end |
#order_id ⇒ Object
A globally-unique identifier for the order. order_id?: String;
19 20 21 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 19 def order_id @order_id end |
#order_id_path ⇒ Object
The URL for the order in your system or store. order_id_path?: String;
23 24 25 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 23 def order_id_path @order_id_path end |
#order_number ⇒ Object
A unique, human-readable identifier for the order. order_number?: String;
127 128 129 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 127 def order_number @order_number end |
#order_promised_delivery_date ⇒ Object
The promised delivery date of the order. It uses the format YYYY-MM-DD. This has no timezone and uses whatever date you provide. Since other EDDs use the shipment recipient’s timezone, we suggest following the same logic here. order_promised_delivery_date?: String;
35 36 37 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 35 def order_promised_delivery_date @order_promised_delivery_date end |
#origin_city ⇒ Object
The city of the sender’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. origin_city?: String;
83 84 85 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 83 def origin_city @origin_city end |
#origin_country_iso3 ⇒ Object
The for more details. origin_country_iso3?: String;
75 76 77 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 75 def origin_country_iso3 @origin_country_iso3 end |
#origin_postal_code ⇒ Object
The postal of the sender’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. origin_postal_code?: String;
87 88 89 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 87 def origin_postal_code @origin_postal_code end |
#origin_raw_location ⇒ Object
The sender address that the shipment is shipping from. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. origin_raw_location?: String;
91 92 93 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 91 def origin_raw_location @origin_raw_location end |
#origin_state ⇒ Object
The state of the sender’s address. This can help AfterShip with various functions like tracking, carrier auto-detection and auto-correction, calculating an EDD, etc. origin_state?: String;
79 80 81 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 79 def origin_state @origin_state end |
#pickup_location ⇒ Object
Shipment pickup location for receiver pickup_location?: String;
43 44 45 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 43 def pickup_location @pickup_location end |
#pickup_note ⇒ Object
Shipment pickup note for receiver pickup_note?: String;
47 48 49 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 47 def pickup_note @pickup_note end |
#shipment_tags ⇒ Object
Used to add tags to your shipments to help categorize and filter them easily. shipment_tags?: String[];
135 136 137 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 135 def @shipment_tags end |
#shipment_type ⇒ Object
The carrier service type for the shipment. If you provide info for this field, AfterShip will not update it with info from the carrier. shipment_type?: String;
131 132 133 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 131 def shipment_type @shipment_type end |
#shipping_method ⇒ Object
The shipping_method string refers to the chosen method for delivering the package. Merchants typically offer various shipping methods to consumers during the checkout process, such as, Local Delivery, Free Express Worldwide Shipping, etc shipping_method?: String;
167 168 169 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 167 def shipping_method @shipping_method end |
#slug ⇒ Object
Unique courier code. Get courier codes . slug?: String;
11 12 13 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 11 def slug @slug end |
#slug_group ⇒ Object
Slug group is a group of slugs which belong to same courier. For example, when you inpit “fedex-group” as slug_group, AfterShip will detect the tracking with “fedex-uk”, “fedex-fims”, and other slugs which belong to “fedex”. It cannot be used with slug at the same time. ( slug_group?: SlugGroupV1;
119 120 121 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 119 def slug_group @slug_group end |
#smses ⇒ Object
The phone number(s) to receive sms notifications. Enter ‘+` andarea `code before` phone number. Accept either array or comma separated as input. Supports up to 3 phone numbers. smses?: String[];
67 68 69 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 67 def smses @smses end |
#title ⇒ Object
By default this field shows the tracking_number, but you can customize it as you wish with any info (e.g. the order number). title?: String;
15 16 17 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 15 def title @title end |
#tracking_account_number ⇒ Object
Additional field required by some carriers to retrieve the tracking info. The shipper’s carrier account number. Refer to our article on for more details. tracking_account_number?: String;
51 52 53 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 51 def tracking_account_number @tracking_account_number end |
#tracking_destination_country ⇒ Object
(Legacy) Replaced by destination_country_iso3. Additional field required by some carriers to retrieve the tracking info. The destination country/region of the shipment. Refer to our article on for more details. tracking_destination_country?: String;
151 152 153 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 151 def tracking_destination_country @tracking_destination_country end |
#tracking_key ⇒ Object
Additional field required by some carriers to retrieve the tracking info. A type of tracking credential required by some carriers. Refer to our article on for more details. tracking_key?: String;
55 56 57 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 55 def tracking_key @tracking_key end |
#tracking_number ⇒ Object
Tracking number of a shipment.Duplicated tracking numbers, tracking numbers with invalid tracking number format will not be accepted.We only accept tracking numbers with length from 4 to 100We currently support the following characters in a tracking number:- A - Z- 0 - 9- - (Hyphen)- . (Period)- _ (Underscore)- / (Slash) tracking_number: String;
7 8 9 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 7 def tracking_number @tracking_number end |
#tracking_origin_country ⇒ Object
(Legacy) Replaced by origin_country_iso3. Additional field required by some carriers to retrieve the tracking info. The origin country/region of the shipment. Refer to our article on for more details. tracking_origin_country?: String;
147 148 149 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 147 def tracking_origin_country @tracking_origin_country end |
#tracking_postal_code ⇒ Object
(Legacy) Replaced by destination_postal_code. Additional field required by some carriers to retrieve the tracking info. The postal code of the recipient’s address. Refer to our article on for more details. tracking_postal_code?: String;
155 156 157 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 155 def tracking_postal_code @tracking_postal_code end |
#tracking_ship_date ⇒ Object
Additional field required by some carriers to retrieve the tracking info. The date the shipment was sent, using the format YYYYMMDD. Refer to our article on for more details. tracking_ship_date?: String;
59 60 61 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 59 def tracking_ship_date @tracking_ship_date end |
#tracking_state ⇒ Object
(Legacy) Replaced by destination_state. Additional field required by some carriers to retrieve the tracking info. The state/province of the recipient’s address. Refer to our article on for more details. tracking_state?: String;
159 160 161 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 159 def tracking_state @tracking_state end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 466 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model klass = AftershipAPI::Model.const_get(type) klass.build_from_hash(value) end end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 393 def self.attribute_map { :'tracking_number' => :'tracking_number', :'slug' => :'slug', :'title' => :'title', :'order_id' => :'order_id', :'order_id_path' => :'order_id_path', :'custom_fields' => :'custom_fields', :'language' => :'language', :'order_promised_delivery_date' => :'order_promised_delivery_date', :'delivery_type' => :'delivery_type', :'pickup_location' => :'pickup_location', :'pickup_note' => :'pickup_note', :'tracking_account_number' => :'tracking_account_number', :'tracking_key' => :'tracking_key', :'tracking_ship_date' => :'tracking_ship_date', :'emails' => :'emails', :'smses' => :'smses', :'customer_name' => :'customer_name', :'origin_country_iso3' => :'origin_country_iso3', :'origin_state' => :'origin_state', :'origin_city' => :'origin_city', :'origin_postal_code' => :'origin_postal_code', :'origin_raw_location' => :'origin_raw_location', :'destination_country_iso3' => :'destination_country_iso3', :'destination_state' => :'destination_state', :'destination_city' => :'destination_city', :'destination_postal_code' => :'destination_postal_code', :'destination_raw_location' => :'destination_raw_location', :'note' => :'note', :'slug_group' => :'slug_group', :'order_date' => :'order_date', :'order_number' => :'order_number', :'shipment_type' => :'shipment_type', :'shipment_tags' => :'shipment_tags', :'courier_connection_id' => :'courier_connection_id', :'next_couriers' => :'next_couriers', :'tracking_origin_country' => :'tracking_origin_country', :'tracking_destination_country' => :'tracking_destination_country', :'tracking_postal_code' => :'tracking_postal_code', :'tracking_state' => :'tracking_state', :'location_id' => :'location_id', :'shipping_method' => :'shipping_method', } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 442 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(key) && attributes[key].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[key].is_a?(Array) transformed_hash["#{key}"] = attributes[key].map { |v| _deserialize($1, v) } end elsif !attributes[key].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[key]) end end new(transformed_hash) end |
.openapi_types ⇒ Object
Attribute type mapping.
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 346 def self.openapi_types { :'tracking_number' => :'String', :'slug' => :'String', :'title' => :'String', :'order_id' => :'String', :'order_id_path' => :'String', :'custom_fields' => :'Object', :'language' => :'String', :'order_promised_delivery_date' => :'String', :'delivery_type' => :'String', :'pickup_location' => :'String', :'pickup_note' => :'String', :'tracking_account_number' => :'String', :'tracking_key' => :'String', :'tracking_ship_date' => :'String', :'emails' => :'Array<String>', :'smses' => :'Array<String>', :'customer_name' => :'String', :'origin_country_iso3' => :'String', :'origin_state' => :'String', :'origin_city' => :'String', :'origin_postal_code' => :'String', :'origin_raw_location' => :'String', :'destination_country_iso3' => :'String', :'destination_state' => :'String', :'destination_city' => :'String', :'destination_postal_code' => :'String', :'destination_raw_location' => :'String', :'note' => :'String', :'slug_group' => :'SlugGroupV1', :'order_date' => :'String', :'order_number' => :'String', :'shipment_type' => :'String', :'shipment_tags' => :'Array<String>', :'courier_connection_id' => :'String', :'next_couriers' => :'Array<NextCouriersTrackingCreateTrackingRequest>', :'tracking_origin_country' => :'String', :'tracking_destination_country' => :'String', :'tracking_postal_code' => :'String', :'tracking_state' => :'String', :'location_id' => :'String', :'shipping_method' => :'String', } end |
Instance Method Details
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
533 534 535 536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 533 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
512 513 514 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 512 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
518 519 520 521 522 523 524 525 526 527 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 518 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_json(*a) ⇒ Object
547 548 549 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 547 def to_json(*a) to_hash.to_json(*a) end |
#to_s ⇒ String
Returns the string representation of the object
506 507 508 |
# File 'lib/aftership-tracking-sdk/models/tracking_create_tracking_request.rb', line 506 def to_s to_hash.to_s end |