Class: AftershipAPI::Model::TrackingCustomers

Inherits:
Object
  • Object
show all
Defined in:
lib/aftership-tracking-sdk/models/tracking_customers.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TrackingCustomers

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 31

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AftershipAPI::TrackingCustomers` initialize method"
  end

  attributes = attributes.each_with_object({}) { |(k, v), h|
    h[k.to_sym] = v
  }

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end
end

Instance Attribute Details

#emailObject

Email address(es) to receive email notifications. email?: String;



19
20
21
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 19

def email
  @email
end

#idObject

The customer's identifier on the merchant or platform (for example, Shopify) side. id?: String;



27
28
29
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 27

def id
  @id
end

#languageObject

The preferred language of the customer. If you have set up AfterShip notifications in different languages, we use this to send the tracking updates to the customer in their preferred language. language?: String;



23
24
25
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 23

def language
  @language
end

#nameObject

Customer name associated with the tracking. name?: String;



11
12
13
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 11

def name
  @name
end

#phone_numberObject

The phone number(s) to receive SMS notifications. Phone numbers should begin with a + sign and include the area code. phone_number?: String;



15
16
17
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 15

def phone_number
  @phone_number
end

#roleObject

The role of the customer, indicating whether the customer is an individual or a company. role?: String;



7
8
9
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 7

def role
  @role
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type (String)

    Data type

  • value (String)

    Value to be deserialized

Returns:

  • (Object)

    Deserialized data



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 116

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    klass = AftershipAPI::Model.const_get(type)
    klass.build_from_hash(value)
  end
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 78

def self.attribute_map
  {
    :'role' => :'role',
    :'name' => :'name',
    :'phone_number' => :'phone_number',
    :'email' => :'email',
    :'language' => :'language',
    :'id' => :'id',
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 92

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(key) && attributes[key].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[key].is_a?(Array)
        transformed_hash["#{key}"] = attributes[key].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[key].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[key])
    end
  end
  new(transformed_hash)
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 66

def self.openapi_types
  {
    :'role' => :'String',
    :'name' => :'String',
    :'phone_number' => :'String',
    :'email' => :'String',
    :'language' => :'String',
    :'id' => :'String',
  }
end

Instance Method Details

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 183

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



162
163
164
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 162

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



168
169
170
171
172
173
174
175
176
177
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 168

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?

    hash[param] = _to_hash(value)
  end
  hash
end

#to_json(*a) ⇒ Object



197
198
199
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 197

def to_json(*a)
  to_hash.to_json(*a)
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



156
157
158
# File 'lib/aftership-tracking-sdk/models/tracking_customers.rb', line 156

def to_s
  to_hash.to_s
end